/*----------------------------------------------------------------------------------

File Name: PESC_API.H

Description: This file contains all of the definitions and constants used 
			for the PCOS Series printer escape functions interface.

-----------------------------------------------------------------------------------*/
#ifndef PESC_API_H
#define PESC_API_H

#define DllExport __declspec(dllexport)

// PEscape function prototypes
int _stdcall PEscape(int iEscape, int iParam, HANDLE hPrinter, DWORD dwPrinterNum);
int _stdcall PEscapeEx(int iEscape, int iParam, char *lpszPrinterName, BYTE *pbyData, DWORD dwDataSize, HANDLE hPrinterIn);
DWORD _stdcall GetStatus(int iStatusRead, char *lpszPrinterName, HANDLE hPrinter);
DWORD _stdcall GetStatusNow(int iStatusRead, char *lpszPrinterName, HANDLE hPrinter);
int _stdcall SendString(BYTE *lpString, DWORD dwParmCount, char* lpszPrinterName, HANDLE hPrinter);
int _stdcall AllowErrorMessages(int Flag);
int _stdcall SendReadString(BYTE *lpSend, BYTE *lpRead, DWORD dwTimeOut, char* lpszPrinterName, HANDLE hPrinterIn);int _stdcall SendReadString(BYTE *lpSend, BYTE *lpRead, DWORD dwTimeOut, char* lpszPrinterName, HANDLE hPrinterIn);



// Printer Name definitions
#define PRINTERNAME_81P "PcOS Series 81"
#define PRINTERNAME_82P "PcOS Series 82"

#define PRINTERNAME_80  "Ithaca Model 80"
#define PRINTERNAME_80C "Ithaca Model 80 Compressed"
#define PRINTERNAME_81  "Ithaca Model 81"
#define PRINTERNAME_81C "Ithaca Model 81 Compressed"
#define PRINTERNAME_82  "Ithaca Model 82"
#define PRINTERNAME_82C "Ithaca Model 82 Compressed"


#define PRINTERNAME_91 "PcOS Series 91"
#define PRINTERNAME_92 "PcOS Series 92"
#define PRINTERNAME_93 "PcOS Series 93"
#define PRINTERNAME_94 "PcOS Series 94"
#define PRINTERNAME_98 "PcOS Series 98"
#define PRINTERNAME_151 "PcOS Series 151"
#define PRINTERNAME_152 "PcOS Series 152"
#define PRINTERNAME_153 "PcOS Series 153"
#define PRINTERNAME_154 "PcOS Series 154"

//
// PcOS PEscape ordinals.
//
#define PE_LOADRECEIPT				900
#define PE_EJECTFORM				901
#define PE_OPENCASHDRAWER			902
#define PE_OPENFORMASSEMBLY			903
#define PE_CLOSEFORMASSEMBLY		904
#define PE_DISABLEPAPERERR			905
#define PE_ENABLEPAPERERR			906
#define PE_CONTROLGRAPHICSAVE		907
#define PE_CONTROLFEATURES			908
#define PE_CUTRECEIPT				909
#define PE_DUALSTATION				910
#define PE_AUTOLOADVALIDATION		911
#define PE_AUTOLOADSLIP				912
#define PE_SELECTCHARSET			913
#define PE_SELECTCODEPAGE			914
#define PE_SELECTLANGTABLE			915
#define PE_PRINTBARCODE				916
#define PE_SELECTEPOSCDPAGE			917



//(Series 90) included for compatibility w/ beta version
#define PE90_LOADRECEIPT				PE_LOADRECEIPT
#define PE90_EJECTFORM					PE_EJECTFORM
#define PE90_OPENCASHDRAWER				PE_OPENCASHDRAWER
#define PE90_OPENFORMASSEMBLY			PE_OPENFORMASSEMBLY
#define PE90_CLOSEFORMASSEMBLY			PE_CLOSEFORMASSEMBLY
#define PE90_DISABLEPAPERERR			PE_DISABLEPAPERERR
#define PE90_ENABLEPAPERERR				PE_ENABLEPAPERERR
#define PE90_CONTROLGRAPHICSAVE			PE_CONTROLGRAPHICSAVE
#define PE90_CONTROLFEATURES			PE_CONTROLFEATURES
#define PE90_CUTRECEIPT					PE_CUTRECEIPT
#define PE90_DUALSTATION				PE_DUALSTATION
#define PE90_AUTOLOADVALIDATION			PE_AUTOLOADVALIDATION
#define PE90_AUTOLOADSLIP				PE_AUTOLOADSLIP
#define PE90_SELECTCHARSET				PE_SELECTCHARSET
#define PE90_SELECTCODEPAGE				PE_SELECTCODEPAGE
#define PE90_SELECTLANGTABLE			PE_SELECTLANGTABLE
#define PE90_PRINTBARCODE				PE_PRINTBARCODE






//----------------------------------------------------------------------------------						
// PcOS Series Constants uses as parameters to PEscapes
//----------------------------------------------------------------------------------						
#define MD_PRINTBUFFER					0		// print graphics save buffer
#define MD_STARTRECORD					1		// starts recording capture buffer
#define MD_STOPRECORDNOSAVE 			2		// stops recording, no store
#define MD_STOPRECORDSAVE				3		// stops recording, stores capture buffer
#define MD_DISABLEQUIET					0		// disables quiet mode
#define MD_ENABLEQUIET					1		// enables quiet mode
#define MD_ENABLEIPCL					5		// enables IPCL commands
#define MD_DISABLEIPCL					4		// disables IPCL commands
#define MD_PARTIALCUT					0		// partial cut 
#define MD_FULLCUT						1		// full cut
#define MD_ALIGNBOTTOM					1		// form insertion to bottom of guide
#define MD_ALIGNRIGHT					2		// form insertion to right of guide
#define MD_ALIGNBOTH					3		// form insertion to right and bottom
#define MD_DRAWER0						0		// cash drawer 1 
#define MD_DRAWER1						1		// cash drawer 1 
#define MD_DRAWER2						2		// cash drawer 2 
#define MD_DUALSTATION  				1		// selects dual station operation
#define MD_SINGLESTATION				0		// selects single station operation
#define MD_CHARSET1						1		// character set 1
#define MD_CHARSET2						2		// character set 2

//----------------------------------------------------------------------------------						
// These constants are for Language Table selection
// The values are the constants to send for each language table
// They are used as the parameter to SelectLanguageTable
// NOTE that Danish1, Japanese and Spanish1 are not supported here
//----------------------------------------------------------------------------------						
#define LANGUAGETABLE_USA1				64
#define LANGUAGETABLE_USA2				65
#define LANGUAGETABLE_FRENCH			68
#define LANGUAGETABLE_GERMAN			67
#define LANGUAGETABLE_BRITISH			66
#define LANGUAGETABLE_SWEDISH			69
#define LANGUAGETABLE_ITALIAN			73
#define LANGUAGETABLE_NORWEGIAN			71
#define LANGUAGETABLE_DANISH			70
#define LANGUAGETABLE_SPANISH			75
#define LANGUAGETABLE_LATAMERICAN		76
#define LANGUAGETABLE_FRCANADIAN		74
#define LANGUAGETABLE_DUTCH				72
#define LANGUAGETABLE_PUBLISHER			90

#define LANGUAGETABLE_MAX				90
#define LANGUAGETABLE_MIN				64


//----------------------------------------------------------------------------------						
// Code Page Constants
//----------------------------------------------------------------------------------						
#define CODEPAGE_ENGLISH				437
#define CODEPAGE_LATIN1					850
#define CODEPAGE_LATIN2					852
#define CODEPAGE_PORTUGESE				860
#define CODEPAGE_FRENCHCANADIAN			863
#define CODEPAGE_NORDIC					865
#define CODEPAGE_CYRILLIC2				866


//----------------------------------------------------------------------------------						
// These constants are for selecting the validation mode in the call
// to Get90Form.
//----------------------------------------------------------------------------------						
#define ALIGN_FORMBOTH					0 		// align to right and botttom
#define ALIGN_FORMBOTTOM    			1		// align to bottom only
#define ALIGN_FORMRIGHT					2		// align to right only


//----------------------------------------------------------------------------------						
// Bar Code Constants
//----------------------------------------------------------------------------------						
#define		MD_BAR_2OF5   			190   	// bar code 2 of 5 standard
#define		MD_BAR_3OF9  			191   	// bar code 39 standard
#define		MD_BAR_128				192   	// bar code 128 standard
#define 	MD_BAR_UPCA				193		// bar code UPC A constant
#define 	MD_BAR_EAN13			194		// bar code EAN-13 constant
#define 	MD_BAR_UPCE				195		// bar code UPC E constant
#define 	MD_BAR_EAN8				196		// bar code EAN-8 constant
#define 	MD_BAR_CODABAR			197		// bar code CODABAR constant
#define 	MD_BAR_93				198		// bar code 93 constant

#define		MD_MAXBAR2OF5			20		// the maximum number of bytes allowed in
											// an interleaved 2 of 5 bar code.
#define		MD_MAXBARCODE39			10		// the maximum number of bytes allowed in
											// bar code 39
#define		MD_MAXBARCODE128		10		// the maximum number of bytes allowed in
											// bar code 128
#define		MD_MAXBARCODEUPCA		11		// the maximum number of bytes allowed in
											// bar code UPC A
#define		MD_MAXBARCODEUPCE		11		// the maximum number of bytes allowed in
											// bar code UPC E
#define		MD_MAXBARCODEEAN13		12		// the maximum number of bytes allowed in
											// bar code EAN-13
#define		MD_MAXBARCODEEAN8		7		// the maximum number of bytes allowed in
											// bar code EAN-8
#define		MD_MAXBARCODECODABAR	255		// the maximum number of bytes allowed in
											// bar code CODABAR
#define		MD_MAXBARCODE93			255		// the maximum number of bytes allowed in
											// bar code CODE93

//----------------------------------------------------------------------------------						
// Status request ordinals
//----------------------------------------------------------------------------------						
//ENQ1
#define    CASHSTATUS1			190		// inquire cash drawer 1 status
                        	   			// ACK=closed; NAK=open
//ENQ2
#define    CASHSTATUS2			191		// inquire cash drawer 2 status
                        	   			// ACK=closed; NAK=open
//ENQ3
#define    RECEIPTLOW			192		// inquire receipt paper low
                        	   			// ACK=paper okay;NAK=paper low
//ENQ4
#define    RECEIPTSTAT			193		// inquire receipt paper status
                        	   			// ACK=paper present;NAK=no paper  
//ENQ5
#define    FRONTSENSORSTAT		194		// inquire front sensor status
                        	   			// ACK=clear;NAK=covered
//ENQ6
#define    TOPSENSORSTAT		195		// inquire top sensor status
                        	   			// ACK=clear;NAK=covered
//ENQ7
#define    FORMSCLAMPSTAT		196		// inquire forms clamp status
                        	   			// ACK=clamp closed;NAK=clamp open
//ENQ8
#define    COVERSTAT     		197		// inquire cover status
                        	   			// ACK=cover is closed;NAK=cover is open
//ENQ9
#define    BUFFERSTAT    		198		// inquire buffer status
                        	   			// ACK=buffer is empty;NAK=buffer not empty
//ENQ10
#define    PRINTERRESET 		199		// request printer reset (series only)
                        	   			// ACK=command accepted;NAK=command rejected
//ENQ11
#define    PWRCYCLESTAT 		200		// inquire power cycle status
                        	   			// ACK=printer power cycled since last ENQ11
                               			// NAK=power NOT cycled since last ENQ11

#define	   ALLSTATUS			201		// inquire all status from the printer as packed bits

#define	   WAITMODE				202		// inquire printer wait mode


//compatibility with early beta release
#define    CASH90STATUS1		CASHSTATUS1
#define    CASH90STATUS2		CASHSTATUS2
#define    RECEIPT90LOW			RECEIPTLOW
#define    RECEIPT90STAT		RECEIPTSTAT
#define    FRONTSENSOR90STAT	FRONTSENSORSTAT
#define    TOPSENSOR90STAT		TOPSENSORSTAT
#define    FORMSCLAMP90STAT		FORMSCLAMPSTAT	
#define    COVER90STAT     		COVERSTAT
#define    BUFFER90STAT    		BUFFERSTAT
#define    PRINTERRESET90 		PRINTERRESET
#define    PWRCYCLE90STAT 		PWRCYCLESTAT




//----------------------------------------------------------------------------------						
// Status return values
//----------------------------------------------------------------------------------						
#define MD_SUCCESS      				0x7777
#define MD_FAILURE      				0x5555
#define MD_BADPARAM     				0x4444
#define MD_NOTAPPLICABLE				0x3333
#define MD_CANCELED     				0x2222
#define MD_TIMEOUT      				0x1111
#define MD_CANTTELL     				0x6666
#define MD_ACK							0x8888
#define MD_NAK							0x9999
#define MD_PAROFFLINE     				MD_CANTTELL



#define    MDBIT_ALWAYSZERO		0x4000		// PREVENTS COLLISION WITH MD_FAILURE & MD_BADPARAM
#define    MDBIT_CASH1CLOSE		0x0002		// inquire cash drawer 1 status
#define    MDBIT_CASH2CLOSE		0x0004		// inquire cash drawer 2 status
#define    MDBIT_RECEIPTLOW		0x0008		// inquire receipt paper low
#define    MDBIT_RECEIPTOUT		0x0010		// inquire receipt paper status
#define    MDBIT_FRONTSENSOR	0x0020		// inquire front sensor status
#define    MDBIT_TOPSENSOR		0x0040		// inquire top sensor status
#define    MDBIT_FORMSCLAMP		0x0080		// inquire forms clamp status
#define    MDBIT_COVERCLOSED	0x0100		// inquire cover status
#define    MDBIT_BUFFEREMPTY	0x0200		// inquire buffer status
#define    MDBIT_PWRCYCLESTAT	0x0400		// inquire power cycle status


#define    MDBIT_RECEIPTSEL		0x0800		// inquire receipt selected
#define    MDBIT_VALIDATIONSEL	0x1000		// inquire validation selected
#define    MDBIT_SLIPSEL		0x2000		// inquire slip selected
#define    MDBIT_WAITFORFORM	0x0001		// inquire waiting for form

#define    MDBIT_PRINTERERROR	0x008000	// inquire printer is in a error state
#define    MDBIT_PRINTERWAITING	0x010000	// inquire waiting for somthing to happen(user intervention)
#define    MDBIT_PRINTEROFFLINE	0x020000	// inquire printer is in a state that 
											// would normally cause it to be off-line

#endif 	//PESC_API_H

